@@ -30,10 +30,14 @@ class ADObject:
             print('Error decoding field %s' % field)
             raise e
 
-    def bytes(self, field) -> int:
+    def bytes_int(self, field) -> int:
         if field in self.object:
             return int.from_bytes(self.field(field), 'big')
 
+    def bytes(self, field) -> bytes:
+        if field in self.object:
+            return self.field(field)
+
     def hex(self, field) -> int:
         if field in self.object:
             return int(self.field(field), 16)
@@ -46,4 +50,5 @@ class ADObject:
     def date_string(self, field) -> datetime:
         data = self.string(field)
         # 2020 09 09 08:56:44.0Z
-        return datetime.strptime(data, '%Y%m%d%H%M%S.0Z')
+        if data:
+            return datetime.strptime(data, '%Y%m%d%H%M%S.0Z')
